@@ -7,6 +7,12 @@
 
 RCS CHANGE LOG:
 $Log: dorandom.c,v $
+Revision 1.1.1.1  2001/05/17 17:11:01  elgreen
+Initial checkin
+
+Revision 1.5  2000/12/12 16:41:21  eric
+aescrypt 0.6 (large patch by Peter Pentchev).
+
 Revision 1.4  2000/04/24 19:46:57  eric
 More autoconf tweaks. Changed to using Counterpane's TwoFish rather than
 Dr. Gladman's TwoFish in an attempt to fix the big endian/little endian
@@ -18,7 +24,7 @@ Daily checkin...
 Revision 1.1  2000/03/28 23:54:28  eric
 Initial checkin -- aescrypt/aesget
 
-$Date: 2000/04/24 19:46:57 $
+$Date: 2001/05/17 17:11:01 $
 
 */
 
